@@ -27,7 +27,14 @@ from pulp_rpm.app.constants import (
     SKIP_TYPES,
     SYNC_POLICY_CHOICES,
 )
-from pulp_rpm.app.models import RpmDistribution, RpmPublication, RpmRemote, RpmRepository, UlnRemote
+from pulp_rpm.app.models import (
+    RpmDistribution,
+    RpmPackageSigningService,
+    RpmPublication,
+    RpmRemote,
+    RpmRepository,
+    UlnRemote,
+)
 from pulp_rpm.app.schema import COPY_CONFIG_SCHEMA
 from urllib.parse import urlparse
 
@@ -56,6 +63,24 @@ class RpmRepositorySerializer(RepositorySerializer):
         required=False,
         allow_null=True,
     )
+    package_signing_service = RelatedField(
+        help_text="A reference to an associated package signing service.",
+        view_name="signing-services-detail",
+        queryset=RpmPackageSigningService.objects.all(),
+        many=False,
+        required=False,
+        allow_null=True,
+    )
+    package_signing_fingerprint = serializers.CharField(
+        help_text=_(
+            "The pubkey V4 fingerprint (160 bits) to be passed to the package signing service."
+            "The signing service will use that on signing operations related to this repository."
+        ),
+        max_length=40,
+        required=False,
+        allow_blank=True,
+        default="",
+    )
     retain_package_versions = serializers.IntegerField(
         help_text=_(
             "The number of versions of each package to keep in the repository; "
@@ -123,6 +148,26 @@ class RpmRepositorySerializer(RepositorySerializer):
         help_text=_("A JSON document describing config.repo file"),
     )
 
+    def to_representation(self, instance):
+        data = super().to_representation(instance)
+        # Import workflow may cause these fields to be stored as "" in the database
+        # This ensure the correct type of  None | Enum in the response
+        for field in (
+            "checksum_type",
+            "metadata_checksum_type",
+            "package_checksum_type",
+            "compression_type",
+            "layout",
+        ):
+            field_data = data.get(field)
+            if field_data == "":
+                data[field] = None
+        # The current API field definition expects empty string for nullable values,
+        # but some migration paths can set an empty string to none in the database.
+        if "package_signing_fingerprint" in data and data["package_signing_fingerprint"] is None:
+            data["package_signing_fingerprint"] = ""
+        return data
+
     def validate(self, data):
         """Validate data."""
         for field in ("checksum_type", "metadata_checksum_type", "package_checksum_type"):
@@ -224,6 +269,8 @@ class RpmRepositorySerializer(RepositorySerializer):
         fields = RepositorySerializer.Meta.fields + (
             "autopublish",
             "metadata_signing_service",
+            "package_signing_service",
+            "package_signing_fingerprint",
             "retain_package_versions",
             "checksum_type",
             "metadata_checksum_type",
